@@ -3,6 +3,7 @@ from datetime import datetime
 from enum import Enum
 
 
+
 class FinancialStatement(Enum):
     """A wrapper enum for common and tested regex to find specific documents"""
     INCOME_STATEMENT = re.compile(r"operation|income|earnings|revenues|loss", re.IGNORECASE)
@@ -17,7 +18,7 @@ class XBRLType(Enum):
     PRE = ("pre",)
 
     # Required
-    LAB = ("lab",)
+    LABEL = ("lab",)
     SCHEMA = ("sch", "xsd")
     DATA = ("xml", "ins")
 
@@ -25,7 +26,7 @@ class XBRLType(Enum):
     def get(cls, item):
         """
         Class method to allow for categorization by string
-        :param item:
+        :param item: A string or object that can do `in` comparisons with a string
         :return:
         """
         item_ref = item.lower()[-7:]
